@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: calc_int.h 534 2004-04-08 19:35:25Z roms $ */
+/* $Id: calc_int.h 1397 2005-07-20 10:55:03Z roms $ */
 
 /*  libticalcs - Ti Calculator library, a part of the TiLP project
  *  Copyright (C) 1999-2004  Romain Lievin
@@ -78,13 +78,13 @@ extern "C" {
   TIEXPORT void TICALL ticalc_action_destroy_array(char **array);
 
   // tikeys.c
-  TIEXPORT const TicalcKey TICALL ticalc_73_keys(unsigned char
+  TIEXPORT TicalcKey TICALL ticalc_73_keys(unsigned char
 						 ascii_code);
-  TIEXPORT const TicalcKey TICALL ticalc_83p_keys(unsigned char
+  TIEXPORT TicalcKey TICALL ticalc_83p_keys(unsigned char
 						  ascii_code);
-  TIEXPORT const TicalcKey TICALL ticalc_89_keys(unsigned char
+  TIEXPORT TicalcKey TICALL ticalc_89_keys(unsigned char
 						 ascii_code);
-  TIEXPORT const TicalcKey TICALL ticalc_92p_keys(unsigned char
+  TIEXPORT TicalcKey TICALL ticalc_92p_keys(unsigned char
 						  ascii_code);
 
   // clock.c
