@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: cmd73.c 792 2004-09-19 14:09:31Z roms $ */
+/* $Id: cmd73.c 1397 2005-07-20 10:55:03Z roms $ */
 
 /*  libticalcs - Ti Calculator library, a part of the TiLP project
  *  Copyright (C) 1999-2004  Romain Lievin
@@ -193,7 +193,7 @@ int ti73_send_REQ(uint16_t varsize, uint8_t vartype, char *varname,
   uint8_t buffer[16] = { 0 };
   uint8_t trans[9];
 
-  tifiles_translate_varname(varname, trans, vartype);
+  tifiles_translate_varname(varname, (char*)trans, vartype);
   DISPLAY
       (" PC->TI: REQ (size=0x%04X=%i, id=%02X, name=<%s>, attr=%i)\n",
        varsize, varsize, vartype, trans, varattr);
@@ -242,7 +242,7 @@ int ti73_send_RTS(uint16_t varsize, uint8_t vartype, char *varname,
   uint8_t buffer[16];
   uint8_t trans[9];
 
-  tifiles_translate_varname(varname, trans, vartype);
+  tifiles_translate_varname(varname, (char*)trans, vartype);
   DISPLAY
       (" PC->TI: RTS (size=0x%04X=%i, id=%02X, name=<%s>, attr=%i)\n",
        varsize, varsize, vartype, trans, varattr);
@@ -268,7 +268,7 @@ int ti73_recv_VAR(uint16_t * varsize, uint8_t * vartype, char *varname,
 		  uint8_t * varattr)
 {
   uint8_t host, cmd;
-  uint8_t buffer[16] = { 0 };
+  uint8_t buffer[65536+6] = { 0 };
   uint16_t length;
   uint8_t trans[9];
 
@@ -289,7 +289,7 @@ int ti73_recv_VAR(uint16_t * varsize, uint8_t * vartype, char *varname,
   varname[8] = '\0';
   *varattr = (buffer[12] & 0x80) ? ATTRB_ARCHIVED : ATTRB_NONE;
 
-  tifiles_translate_varname(varname, trans, *vartype);
+  tifiles_translate_varname(varname, (char*)trans, *vartype);
   printl2(0, " (size=0x%04X=%i, id=%02X, name=<%s>, attrb=%i)",
 	  *varsize, *varsize, *vartype, trans, *varattr);
   printl2(0, ".\n");
@@ -302,7 +302,7 @@ int ti73_recv_VAR2(uint16_t * length, uint8_t * type, char *name,
 		   uint16_t * offset, uint16_t * page)
 {
   uint8_t host, cmd;
-  uint8_t buffer[16] = { 0 };
+  uint8_t buffer[65536+6] = { 0 };
   uint16_t len;
 
   printl2(0, " TI->PC: VAR");
@@ -334,7 +334,7 @@ int ti73_recv_CTS(uint16_t length)
 {
   uint8_t host, cmd;
   uint16_t len;
-  uint8_t buffer[5];
+  uint8_t buffer[65536+6];
 
   printl2(0, " TI->PC: CTS");
   TRYF(recv_packet(&host, &cmd, &len, buffer));
@@ -353,7 +353,7 @@ int ti73_recv_SKIP(uint8_t * rej_code)
 {
   uint8_t host, cmd;
   uint16_t length;
-  uint8_t buffer[5];
+  uint8_t buffer[65536+6];
   *rej_code = 0;
 
   printl2(0, " TI->PC: SKIP");
@@ -394,7 +394,7 @@ int ti73_recv_ACK(uint16_t * status)
 {
   uint8_t host, cmd;
   uint16_t length;
-  uint8_t buffer[5];
+  uint8_t buffer[65536+6];
 
   printl2(0, " TI->PC: ACK");
   TRYF(recv_packet(&host, &cmd, &length, buffer));
@@ -414,7 +414,7 @@ int ti73_recv_RTS(uint16_t * varsize, uint8_t * vartype, char *varname,
 		  uint8_t * varattr)
 {
   uint8_t host, cmd;
-  uint8_t buffer[16];
+  uint8_t buffer[65536+6];
   uint8_t trans[9];
 
 
@@ -428,7 +428,7 @@ int ti73_recv_RTS(uint16_t * varsize, uint8_t * vartype, char *varname,
   varname[8] = '\0';
   *varattr = (buffer[12] & 0x80) ? ATTRB_ARCHIVED : ATTRB_NONE;
 
-  tifiles_translate_varname(varname, trans, *vartype);
+  tifiles_translate_varname(varname, (char*)trans, *vartype);
   printl2(0, " (size=0x%04X=%i, id=%02X, name=<%s>, attrb=%i)",
 	  *varsize, *varsize, *vartype, trans, *varattr);
   printl2(0, ".\n");
