@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: cmd82.c 732 2004-05-28 21:05:39Z roms $ */
+/* $Id: cmd82.c 1397 2005-07-20 10:55:03Z roms $ */
 
 /*  libticalcs - Ti Calculator library, a part of the TiLP project
  *  Copyright (C) 1999-2004  Romain Lievin
@@ -48,7 +48,7 @@ int ti82_send_VAR(uint16_t varsize, uint8_t vartype, char *varname)
   uint8_t buffer[16];
   uint8_t trans[9];
 
-  tifiles_translate_varname(varname, trans, vartype);
+  tifiles_translate_varname(varname, (char*)trans, vartype);
   printl2(0, " PC->TI: VAR (size=0x%04X=%i, id=%02X, name=<%s>)\n",
 	  varsize, varsize, vartype, trans);
 
@@ -148,7 +148,7 @@ int ti82_send_REQ(uint16_t varsize, uint8_t vartype, char *varname)
   uint8_t buffer[16] = { 0 };
   uint8_t trans[9];
 
-  tifiles_translate_varname(varname, trans, vartype);
+  tifiles_translate_varname(varname, (char*)trans, vartype);
   printl2(0, " PC->TI: REQ (size=0x%04X=%i, id=%02X, name=<%s>)\n",
 	  varsize, varsize, vartype, trans);
 
@@ -178,7 +178,7 @@ int ti82_send_RTS(uint16_t varsize, uint8_t vartype, char *varname)
   uint8_t buffer[16];
   uint8_t trans[9];
 
-  tifiles_translate_varname(varname, trans, vartype);
+  tifiles_translate_varname(varname, (char*)trans, vartype);
   printl2(0, " PC->TI: RTS (size=0x%04X=%i, id=%02X, name=<%s>)\n",
 	  varsize, varsize, vartype, trans);
 
@@ -200,7 +200,7 @@ int ti82_send_RTS(uint16_t varsize, uint8_t vartype, char *varname)
 int ti82_recv_VAR(uint16_t * varsize, uint8_t * vartype, char *varname)
 {
   uint8_t host, cmd;
-  uint8_t buffer[16] = { 0 };
+  uint8_t buffer[65536+6] = { 0 };
   uint16_t length;
   uint8_t trans[9];
 
@@ -225,7 +225,7 @@ int ti82_recv_VAR(uint16_t * varsize, uint8_t * vartype, char *varname)
 
 
 
-  tifiles_translate_varname(varname, trans, *vartype);
+  tifiles_translate_varname(varname, (char*)trans, *vartype);
   printl2(0, " (size=0x%04X=%i, id=%02X, name=<%s>)",
 	  *varsize, *varsize, *vartype, trans);
   printl2(0, ".\n");
@@ -315,7 +315,7 @@ int ti82_recv_ACK(uint16_t * status)
 int ti82_recv_RTS(uint16_t * varsize, uint8_t * vartype, char *varname)
 {
   uint8_t host, cmd;
-  uint8_t buffer[16];
+  uint8_t buffer[65536+6];
   uint8_t trans[9];
 
 
@@ -329,7 +329,7 @@ int ti82_recv_RTS(uint16_t * varsize, uint8_t * vartype, char *varname)
   varname[8] = '\0';
 
 
-  tifiles_translate_varname(varname, trans, *vartype);
+  tifiles_translate_varname(varname, (char*)trans, *vartype);
   printl2(0, " (size=0x%04X=%i, id=%02X, name=<%s>)",
 	  *varsize, *varsize, *vartype, trans);
   printl2(0, ".\n");
