@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: cmd89.c 844 2005-01-29 15:51:58Z roms $ */
+/* $Id: cmd89.c 1397 2005-07-20 10:55:03Z roms $ */
 
 /*  libticalcs - Ti Calculator library, a part of the TiLP project
  *  Copyright (C) 1999-2004  Romain Lievin
@@ -65,10 +65,10 @@ static uint8_t pc_ti9x(void)
 int ti89_send_VAR(uint32_t varsize, uint8_t vartype, char *varname)
 {
   uint8_t buffer[32];
-  uint8_t trans[9];
+  uint8_t trans[32];
   uint8_t extra = (vartype == TI9X_BKUP) ? 0 : 1;
 
-  tifiles_translate_varname(varname, trans, vartype);
+  tifiles_translate_varname(varname, (char*)trans, vartype);
   printl2(0, " PC->TI: VAR (size=0x%08X=%i, id=%02X, name=<%s>)\n",
 	  varsize, varsize, vartype, trans);
 
@@ -260,7 +260,7 @@ int ti89_send_RTS2(uint32_t varsize, uint8_t vartype, char *varname)
 int ti89_recv_VAR(uint32_t * varsize, uint8_t * vartype, char *varname)
 {
   uint8_t host, cmd;
-  uint8_t buffer[32] = { 0 };
+  uint8_t buffer[65536+6] = { 0 };
   uint16_t length;
   uint8_t strl;
   uint8_t flag;
@@ -297,7 +297,7 @@ int ti89_recv_CTS(void)
 {
   uint8_t host, cmd;
   uint16_t length;
-  uint8_t buffer[5];
+  uint8_t buffer[65536+6];
 
   printl2(0, " TI->PC: CTS");
   TRYF(recv_packet(&host, &cmd, &length, buffer));
@@ -316,7 +316,7 @@ int ti89_recv_SKIP(uint8_t * rej_code)
 {
   uint8_t host, cmd;
   uint16_t length;
-  uint8_t buffer[5];
+  uint8_t buffer[65536+6];
   *rej_code = 0;
 
   printl2(0, " TI->PC: SKIP");
@@ -360,7 +360,7 @@ int ti89_recv_ACK(uint16_t * status)
 {
   uint8_t host, cmd;
   uint16_t length;
-  uint8_t buffer[5];
+  uint8_t buffer[65536+6];
 
   printl2(0, " TI->PC: ACK");
   TRYF(recv_packet(&host, &cmd, &length, buffer));
@@ -412,7 +412,7 @@ int ti89_recv_EOT(void)
 int ti89_recv_RTS(uint32_t * varsize, uint8_t * vartype, char *varname)
 {
   uint8_t host, cmd;
-  uint8_t buffer[32] = { 0 };
+  uint8_t buffer[65536+6] = { 0 };
   uint16_t length;
   uint8_t strl;
 
