@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: intrface.c 972 2005-04-24 12:33:06Z roms $ */
+/* $Id: intrface.c 1413 2005-07-21 17:03:13Z roms $ */
 
 /*  libticalcs - Ti Calculator library, a part of the TiLP project
  *  Copyright (C) 1999-2004  Romain Lievin
@@ -19,6 +19,13 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+#if HAVE_LOCALE_H
+#include <locale.h>
+#endif
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
