@@ -1,8 +1,8 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: keys92p.c 2385 2006-05-26 07:44:30Z roms $ */
+/* $Id: keys92p.c 369 2004-03-22 18:45:39Z roms $ */
 
 /*  libticalcs - Ti Calculator library, a part of the TiLP project
- *  Copyright (C) 1999-2005  Romain Livin
+ *  Copyright (C) 1999-2004  Romain Lievin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#include "ticalcs.h"
+#include "calc_def.h"
 
 /*
   Conversion of an PC scancode into an TI scancode.
@@ -32,8 +32,7 @@
 
   The array can be used in reverse order too, at least for the first column...
 */
-const OldCalcKeys_ TI92P_KEYS[] = 
-{
+const TicalcKey TI92P_KEYS[] = {
 /* 0x00, 0-15 */
   {"", "", 0, "", 0, "", 0, "", 0, "", 0},
   {"", "", 0, "", 0, "", 0, "", 0, "", 0},
@@ -310,16 +309,19 @@ const OldCalcKeys_ TI92P_KEYS[] =
 /* 0x100, 256 */
   {"", "", 0, "", 0, "", 0, "", 0},
   {"<-", "BS", 257, "BS", 257, "INS", 4353, "DEL", 8449, "", 0},
-  {"STO->", "STO->", 258, "STO->", 258, "RCL", 4354, "", 8450, "", 0},
+  {"STO->", "STO->", 258, "STO->", 258, "RCL", 4354, "", 8450, "",
+   0},
   {"SIN", "SIN", 259, "SIN", 259, "SIN\200", 4355, "", 8451, "", 0},
   {"COS", "COS", 260, "COS", 260, "COS\200", 4356, "", 8452, "", 0},
   {"TAN", "TAN", 261, "TAN", 261, "TAN\200", 4357, "", 8453, "", 0},
   {"LN", "LN", 262, "LN", 262, "e^x", 4358, "", 8454, "", 0},
-  {"CLEAR", "CLEAR", 263, "CLEAR", 263, "CLEAR", 263, "", 8455, "", 0},
+  {"CLEAR", "CLEAR", 263, "CLEAR", 263, "CLEAR", 263, "", 8455, "",
+   0},
   {"ESC", "ESC", 264, "ESC", 264, "QUIT", 4360, "", 8456, "", 0},
-  {"APPS", "APPS", 265, "APPS", 265, "SWITCH", 4361, "", 8457, "", 0},
+  {"APPS", "APPS", 265, "APPS", 265, "SWITCH", 4361, "", 8457, "",
+   0},
   {"MODE", "MODE", 266, "MODE", 266, "MODE", 266, "", 8458, "", 0},
-  {"ON", "ON", 267, "OFF", 267, "OFF", 267, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0},
   {"F1", "F1", 268, "F1", 268, "F1", 8460, "", 0},
   {"F2", "F2", 269, "F2", 269, "F2", 8461, "", 0},
   {"F3", "F3", 270, "F3", 270, "F3", 8462, "", 0},
@@ -329,7 +331,7 @@ const OldCalcKeys_ TI92P_KEYS[] =
   {"F6", "F6", 273, "F6", 273, "F6", 8465, "", 0},
   {"F7", "F7", 274, "F7", 274, "F7", 8466, "", 0},
   {"F8", "F8", 275, "F8", 275, "F8", 8467, "", 0},
-  {"CHS?", "CHS?", 276, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0},
   {"", "", 0, "", 0, "", 0, "", 0},
   {"", "", 0, "", 0, "", 0, "", 0},
   {"", "", 0, "", 0, "", 0, "", 0},
